@@ -1,5 +1,5 @@
 /* graveman.h
- * Copyright (C) 2004, 2005 Sylvain Cresto <sylvain.cresto@tiscali.fr>
+ * Copyright (C) 2004, 2005 Sylvain Cresto <scresto@gmail.com>
  *
  * This file is part of graveman!
  *
@@ -24,6 +24,7 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/wait.h>
 #include <unistd.h>
 #include <signal.h>
 #include <dirent.h>
@@ -80,9 +81,10 @@
 
 #define MAX_SPEED 54
 
-#define GRAVEUR_ONLY 1
-#define ALL 2
-#define ISO 4
+#define TYPE_ALLWRITER 1
+#define TYPE_ALL 2
+#define TYPE_ISO 4
+#define TYPE_DVDWRITER 8
 
 #define TYPE_CD    1
 #define TYPE_DIR   2
@@ -96,13 +98,24 @@
 #define UPDATE_SIZE     8
 #define UPDATE_SAVEONEXIT_VALUE 16
 
-#define MENU_NEW        0
-#define MENU_UPDATE     1
+#define MENU_NEW        1
+#define MENU_UPDATE     2
+#define COMBO_UPDATE    4
 
 /* gestion CD de boot */
 #define CDBOOT_NONE     0
 #define CDBOOT_IMAGE    1
- 
+
+#define _REMPLISSAGE_VALUE(Ahash, Alist, Asize, Amaxsize, Aprogressbar) \
+    { \
+      gchar *Lprefix = (!strcmp(glade_get_widget_name(GTK_WIDGET(Alist)), "LISTEDATA") ? "data" : "dvddata"); \
+      Asize = (guint64 *)sc_hash_table_lookupv (Ahash, "%ssize", Lprefix); \
+      Amaxsize = (guint64 *)sc_hash_table_lookupv (Ahash, "%smaxsize", Lprefix); \
+      Aprogressbar = sc_hash_table_lookupv(Ahash, "%ssizebar", Lprefix); \
+    }
+
+#define remplirecombo(Acombo, Abasename, Aentry, Adoinit, Aselvalue) remplirecombo_full(Acombo, Abasename, Aentry, Adoinit, Aselvalue, -1)
+  
 typedef enum {
   PB_UPDATE_AUDIO,
   PB_UPDATE_DATA,
@@ -123,6 +136,11 @@ typedef enum {
   DVD_FULLBLANK
 } Ttypeformatdvd;
 
+typedef enum {
+  WRITE_CD,
+  WRITE_DVD
+} Ttypeoperation;
+
 #ifdef ENABLE_MP3
   #define MP3 ".mp3"
 #endif
@@ -175,6 +193,7 @@ typedef struct {
   gint actuperiph;
   gint  type;   /* type 15 = graveur cdrw, 1 = lecteur */
   gshort vitesse;
+  gshort vitessedvd;
   gboolean manual;  /* ajouter manuelement ou non */
 } Tdriveinfo;
 
@@ -189,6 +208,7 @@ typedef struct {
   gchar *basecode;
   gchar *label;
   gboolean defaut;
+  gint filtre;
 } Tmyentry;
 
 typedef struct {
@@ -207,6 +227,9 @@ extern gboolean preparedata(GHashTable *Ahash, GError **Aerror);
 /* dvdrwformat.c */
 extern gboolean perform_format_dvd(GHashTable *Ahash, Ttypeformatdvd Aoperation, GError **Aerror);
 
+/* growisofs.c */
+extern gboolean burn_dvd(GHashTable *Ahash, GError **Aerror);
+
 /* images.c */
 extern GdkPixbuf *GDirIcone;
 extern GdkPixbuf *GFileIcone;
@@ -236,7 +259,7 @@ extern void prepare_menu_images(GHashTable *Ahash);
 /* interface.c */
 extern GSList *Gmedialist;
 extern Tmediaentry Gdefaultmedia[];
-extern void remplirecombovitesse(GtkComboBox *Acombo, gchar *Alecident, gchar *Aselvalue);
+extern void remplire_combo_vitesse(GtkComboBox *Acombo, gchar *Alecident, gchar *Aselvalue);
 extern void show_graverwindow(GHashTable *Ahash, gchar *Aaction, gchar *Atitle);
 extern GtkWidget* create_addfileselection (GtkWindow *AParent);
 extern GtkWidget* create_adddirselection (GtkWindow *AParent);
@@ -248,17 +271,17 @@ extern GtkMenu *create_gtkpopupmenuformatdvd(GHashTable *Ahash);
 extern gboolean gtk_do_eventbuttonpress(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
 extern GtkWidget* create_addpisteselection (GtkWindow *AParent);
 extern GladeXML *create_window_encours(GtkWidget *AParent);
-extern GtkWidget* manage_main_window (guint32 *Aaudiolen, guint32 *Aaudiomaxlen,
-        guint32 *Adatasize, guint32 *Adatamaxsize);
+extern GtkWidget* manage_main_window (guint64 *Aaudiolen, guint64 *Aaudiomaxlen,
+    guint64 *Adatasize, guint64 *Adatamaxsize, guint64 *Advddatasize, guint64 *Advddatamaxsize);
 extern GtkWidget* create_fileselection1 (GtkWindow *AParent, GtkFileChooserAction AType);
 extern void about_graveman (void);
 extern GHashTable *create_dialog_proprietes (GtkWidget *Aparent);
 extern void welcome_to_graveman(void);
-extern void switch_pbar_status(GtkProgressBar *Apbar, guint32 Amaxlen, guint32 Acurlen, Ttypemajpbar Aupdatetext);
+extern void switch_pbar_status(GtkProgressBar *Apbar, guint64 Amaxlen, guint64 Acurlen, Ttypemajpbar Aupdatetext);
 extern void prepare_combobox_graveur(GladeXML *Axml, GHashTable *Ahash, gchar *Abasename);
 extern void prepare_combobox_vitesse(GtkComboBox *Acombobox);
 extern void update_combo_graveur(GHashTable *Ahash);
-extern void prepare_listedata(GtkTreeView *Atreedata);
+extern void prepare_listedata(GtkTreeView *Atreedata, gchar *Atitle);
 extern void prepare_listeaudio(GtkTreeView *Atreeaudio);
 extern void prepare_popups(GladeXML *Axml, GHashTable *Ahash);
 extern void prepare_disable_when_iso(GHashTable *Ahash, gchar *Abasename, const gchar *Afirst, ...);
@@ -269,10 +292,11 @@ extern void manage_combobox_devicebus(GtkComboBox *Acombobox, Tdriveinfo *Adrive
 extern GHashTable *create_dialog_edit_device(GtkWidget *Aparent, Tdriveinfo *Adrive);
 extern GHashTable *create_dialog_add_device(GtkWidget *Aparent);
 extern GHashTable *addmediaformat(GHashTable *Aparent);
-extern void manage_top_menu(GHashTable *Ahash, gint Aaction);
+extern void manage_interface(GHashTable *Ahash, gint Aaction);
 extern void gtk_toggle_top_menu(GtkTreeView *Atopmenu, gpointer Adata);
 extern GHashTable *create_dialog_confirm_operation (GtkWidget *Aparent, gchar *Alabel, 
                       gchar *Acheckboxlbl, gboolean Acheckboxstatus);
+extern GHashTable *create_dialog_select_dvdoperation (GtkWidget *Aparent);
 extern void update_status_bar_display(GHashTable *Ahash);
 extern void show_dvdformatwindow(GHashTable *Ahash, gchar *Atitle, Ttypeformatdvd Aoperation);
 
@@ -286,9 +310,8 @@ extern GladeXML *Gxml;
 extern TProgRequis Glisteprogrequis[];
 extern void config_init();
 extern void clean_config();
-extern gchar *get_config_file_name();
-extern gint is_config_valid();
-extern gint manage_config(GHashTable *Ahash, gshort Aop, GError **Aerror);
+extern gboolean get_config_file(gint Lmode);
+extern gboolean manage_config(GHashTable *Ahash, gshort Aop, GError **Aerror);
 extern gint Gfifosize;
 extern gchar *conf_get_string(gchar *Anom);
 extern gchar *conf_get_string_def(gchar *Anom, gchar *Adefault);
@@ -297,15 +320,16 @@ extern gboolean conf_get_boolean(gchar *Anom);
 extern void restore_last_used_values(GHashTable *Ahash);
 extern void conf_store_value(gchar *Aentry, gchar *Avalue);
 extern void conf_store_int(gchar *Aentry, gint Avalue);
-extern gint write_conf(gchar *AFichier, GError **Aerror);
+extern gboolean write_conf(GError **Aerror);
 extern void maj_proprietes_prog(GHashTable *Ahash);
-extern void remplirecombo (GtkComboBox *Acombo, gchar *Abasename, Tmyentry *Aentry, gboolean Adoinit, gchar *Aselvalue);
+extern void remplirecombo_full (GtkComboBox *Acombo, gchar *Abasename, Tmyentry *Aentry, gboolean Adoinit, gchar *Aselvalue, gint Afiltre);
 extern void remplirecombograveur(GtkComboBox *Acombo, gint Aquoi, gchar *Aselvalue);
 extern void remplirelistegraveur(GtkTreeView *Aliste);
 extern gboolean read_config(GError **Aerror);
 extern void restore_main_window_pos(GtkWidget *Awindow1);
 extern void use_last_dir(GtkFileChooser *Awidget);
 extern void save_last_dir(GtkFileChooser *Awidget);
+extern gboolean test_version();
 
 /* matos.c */
 extern GSList *Glistdrives;
@@ -313,9 +337,11 @@ extern void append_this_drive(Tdriveinfo *Adrive);
 extern void free_this_drive(Tdriveinfo *Adrive);
 extern void free_drives(gboolean Aremovemanu);
 extern void insert_or_update_drive(gchar *Adev, gchar *Amarque, gchar *Amodel, gchar *Aquoi, Tsearchdrive *Adrivedesc);
+extern void get_current_matos(gboolean *Areadcd, gboolean *Awritecdr, gboolean *Awritecdrw, gboolean *Areaddvd, gboolean *Awritedvd);
 extern Tdriveinfo *find_drive(gchar *Aident);
 extern gint get_maxspeed(int Anum);
 extern gboolean burn_data(GHashTable *Ahash, GError **Aerror);
+extern gboolean burn_dvddata(GHashTable *Ahash, GError **Aerror);
 extern gboolean burn_audio(GHashTable *Ahash, GError **Aerror);
 extern gboolean burn_copy(GHashTable *Ahash, GError **Aerror);
 extern gboolean deltempdir(gchar *Ldirpath);
@@ -333,7 +359,8 @@ extern gboolean perform_fix_cd(GHashTable *Ahash, GError **Aerror);
 extern void eject_cd(gchar *Adev, GError **Aerror);
 
 /* mkisofs.c */
-extern gchar *make_image_getextrapara(GHashTable *Ahash);
+extern gboolean check_mkisofs();
+extern gchar *make_image_getextrapara(GHashTable *Ahash, gchar *Aop);
 extern gboolean make_iso(GHashTable *Ahash, GError **Aerror);
 
 /* mp3.c */
@@ -352,21 +379,26 @@ extern gint get_combo_intvalue(GtkWidget *Acombo);
 extern gint make_int(gchar *Abuf);
 extern gshort make_short(gchar *Abuf);
 extern gchar *sc_realloc_cat(gchar *Asep, gchar *Asrc, gchar *Aplus);
-extern gchar *format_length(guint32 Alennbr);
-extern gchar *format_size(guint32 Asize);
+extern gchar *format_length(guint64 Alennbr);
+extern gchar *format_size(guint64 Asize);
 extern gboolean sc_str_has_casesuffix(gchar *Astr, gchar *Asuffix);
 extern gpointer sc_hash_table_lookupv(GHashTable *Ahash, gchar *Akeyformat, ...);
 extern gchar * sc_strescape (const gchar *source);
 extern void sc_line_data_copy(GtkTreeModel *Amodel, GtkTreeIter *Aiterde, GtkTreeIter *Aitervers);
 extern gboolean sc_str_match(gchar *Lpattern, gchar *Lstr);
+extern void exit_prog(gint Apid, gboolean Aabort, GError **Aerror, gchar *Adefmsg);
+extern gint sc_mkdir(const gchar *Aname, mode_t Amode);
 
 /* readcd.c */
-extern gint make_image(GHashTable *Ahash, GError **Aerror);
+extern gboolean make_image(GHashTable *Ahash, GError **Aerror);
 #if 0
 extern gboolean copy_on_the_fly(GtkWidget *Awindow1, GtkWidget *Aparent, GError **Aerror);
 #endif
 
 /* sox.c */
+extern gboolean GsupportMp3;
+extern gboolean GsupportOgg;
+extern gboolean check_sox();
 extern gboolean SoundToCdr(GHashTable *Ahash, gchar *AFichier, gchar *AVers, GError **Aerror);
 
 /* wav.c */
@@ -380,6 +412,8 @@ extern GtkWidget *glade_to_hash(GladeXML *Axml, GHashTable *Ahash, gchar *Akey);
 extern GtkWidget *glade_to_hashv(GladeXML *Axml, GHashTable *Ahash, const gchar *Akeyformat, ...);
 extern void glade_to_hash_list(GladeXML *Axml, GHashTable *Ahash, const gchar *Afirst, ...);
 extern GtkWidget *sc_glade_xml_get_widgetv(GladeXML *Axml, const gchar *Akeyformat, ...);
+extern void set_cursor(GtkWidget *Awindow, GdkCursorType Acursortype);
+extern void unset_cursor(GtkWidget *Awindow);
 
 /* callbacks.c */
 extern void gtk_devices_edit(GtkWidget *Abtn, gpointer Adata);
