@@ -151,7 +151,7 @@ gboolean SoundToCdr(GHashTable *Ahash, gchar *AFichier, gchar *AVers, GError **A
   while (*Lcont > 1 && *Labort == FALSE) {
     gtk_main_iteration(); 
   }
-  exit_prog(*Lpid, Aerror, NULL);
+  exit_prog(*Lpid, *Labort, Aerror, NULL);
 
   g_source_remove(Lcomerrevent);
   g_source_remove(Lcomevent);
